@@ -23,9 +23,8 @@ Example usage: ::
 from __future__ import unicode_literals, absolute_import
 import sys
 import json
-import string as pystring
 from collections import defaultdict
-import logging
+from itertools import chain
 
 from textblob.packages import nltk
 from textblob.decorators import cached_property, requires_nltk_corpus
@@ -46,7 +45,6 @@ from textblob.en import suggest
 # Wordnet interface
 # NOTE: textblob.wordnet is not imported so that the wordnet corpus can be lazy-loaded
 _wordnet = nltk.corpus.wordnet
-logger = logging.getLogger(__name__)
 
 def _penn_to_wordnet(tag):
     '''Converts a Penn corpus tag into a Wordnet tag.'''
@@ -545,16 +543,10 @@ class BaseBlob(StringlikeMixin, BlobComparableMixin):
 
         :rtype: BaseBlob
         '''
-        tok = WordTokenizer()
-        corrected = (Word(w).correct() for w in tok.tokenize(self.raw, include_punc=True))
-        # Separate each token with a space unless the token is a punctuation
-        ret = ''
-        for i, word in enumerate(corrected):
-            # Avoid an extra space at the beginning
-            if word in pystring.punctuation or i == 0:
-                ret = ''.join([ret, word])
-            else:
-                ret = ' '.join([ret, word])
+        # regex matches: contraction or word or punctuation or whitespace
+        tokens = nltk.tokenize.regexp_tokenize(self.raw, "\w*('\w*)+|\w+|[^\w\s]|\s")
+        corrected = (Word(w).correct() for w in tokens)
+        ret = ''.join(corrected)
         return self.__class__(ret)
 
     def _cmpkey(self):
@@ -622,9 +614,9 @@ class TextBlob(BaseBlob):
         '''
         # NLTK's word tokenizer expects sentences as input, so tokenize the
         # blob into sentences before tokenizing to words
-        words = []
-        for sent in self.sentences:
-            words.extend(WordTokenizer().tokenize(sent.raw, include_punc=False))
+        tok = WordTokenizer()
+        words = chain.from_iterable(tok.itokenize(sent.raw, include_punc=False)
+                                    for sent in self.sentences)
         return WordList(words)
 
     @property
@@ -656,10 +648,7 @@ class TextBlob(BaseBlob):
         return self.to_json()
 
     def _create_sentence_objects(self):
-        '''Returns a list of Sentence objects given
-        a list of sentence strings. Attempts to handle sentences that
-        have more than one punctuation mark at the end of the sentence.
-        Examples: "An ellipses is no problem..." or "This is awesome!!!"
+        '''Returns a list of Sentence objects from the raw text.
         '''
         sent_tokenizer = SentenceTokenizer()
         sentence_objects = []
